==> v0.3.7.tar.gz: osrm-backend/DataStructures/QueryEdge.h <==
/*

Copyright (c) 2013, Project OSRM, Dennis Luxen, others
All rights reserved.

Redistribution and use in source and binary forms, with or without modification,
are permitted provided that the following conditions are met:

Redistributions of source code must retain the above copyright notice, this list
of conditions and the following disclaimer.
Redistributions in binary form must reproduce the above copyright notice, this
list of conditions and the following disclaimer in the documentation and/or
other materials provided with the distribution.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
(INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

*/

#ifndef QUERYEDGE_H_
#define QUERYEDGE_H_

#include "TurnInstructions.h"
#include "../typedefs.h"

#include <climits>

struct OriginalEdgeData{
    explicit OriginalEdgeData(
        NodeID viaNode,
        unsigned nameID,
        TurnInstruction turnInstruction
    ) : viaNode(viaNode), nameID(nameID), turnInstruction(turnInstruction) {}
    OriginalEdgeData() : viaNode(UINT_MAX), nameID(UINT_MAX), turnInstruction(UCHAR_MAX) {}
    NodeID viaNode;
    unsigned nameID;
    TurnInstruction turnInstruction;
};

struct QueryEdge {
    NodeID source;
    NodeID target;
    struct EdgeData {
        NodeID id:31;
        bool shortcut:1;
        int distance:30;
        bool forward:1;
        bool backward:1;
    } data;

    bool operator<( const QueryEdge& right ) const {
        if ( source != right.source ) {
            return source < right.source;
        }
        return target < right.target;
    }

    bool operator== ( const QueryEdge& right ) const {
        return ( source == right.source && target == right.target && data.distance == right.data.distance &&
                data.shortcut == right.data.shortcut && data.forward == right.data.forward && data.backward == right.data.backward
                && data.id == right.data.id
        );
    }
};

#endif /* QUERYEDGE_H_ */

==> v0.4.2b.tar.gz: osrm-backend/DataStructures/QueryEdge.h <==
/*

Copyright (c) 2013, Project OSRM, Dennis Luxen, others
All rights reserved.

Redistribution and use in source and binary forms, with or without modification,
are permitted provided that the following conditions are met:

Redistributions of source code must retain the above copyright notice, this list
of conditions and the following disclaimer.
Redistributions in binary form must reproduce the above copyright notice, this
list of conditions and the following disclaimer in the documentation and/or
other materials provided with the distribution.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
(INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

*/

#ifndef QUERYEDGE_H_
#define QUERYEDGE_H_

#include "../typedefs.h"

struct QueryEdge
{
    NodeID source;
    NodeID target;
    struct EdgeData
    {
        NodeID id : 31;
        bool shortcut : 1;
        int distance : 30;
        bool forward : 1;
        bool backward : 1;
    } data;

    bool operator<(const QueryEdge &right) const
    {
        if (source != right.source)
        {
            return source < right.source;
        }
        return target < right.target;
    }

    bool operator==(const QueryEdge &right) const
    {
        return (source == right.source && target == right.target &&
                data.distance == right.data.distance && data.shortcut == right.data.shortcut &&
                data.forward == right.data.forward && data.backward == right.data.backward &&
                data.id == right.data.id);
    }
};

#endif /* QUERYEDGE_H_ */
